@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 515 2008-04-19 08:29:01Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 786 2008-06-24 03:06:55Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -192,6 +192,9 @@ class BaseFrameContainer
 			// カレントのテンプレートIDを設定
 			$gEnvManager->setCurrentTemplateId($curTemplate);
 
+			// バッファリングの準備
+			if (method_exists($this, '_prepareBuffer')) $this->_prepareBuffer($request);
+			
 			// ################### バッファリング開始 ######################
 			// ob_end_flush()までの出力をバッファリングする
 			if ($gEnvManager->getIsMobile()){// 携帯用サイトの場合は出力エンコーディングを変更
@@ -237,13 +240,34 @@ class BaseFrameContainer
 			
 			// 遅延実行ウィジェットの出力を埋め込む
 			$destContents = $gPageManager->lateLaunchWidget($request, $srcContents);
-			echo $destContents;
 			
-			// ページ作成終了処理(HTTPヘッダ出力)
-			$gPageManager->end($request);
+			// 携帯インターフェイスのときのときは、手動変換後、バイナリコード(絵文字等)を埋め込む
+			if ($gEnvManager->getIsMobile()){
+				// コンテンツ変換メソッドがある場合は実行
+				if (method_exists($this, '_convContents')){		
+					$destContents = mb_convert_encoding($destContents, $mobileEncoding, M3_ENCODING);		// 出力するコードに変換
+				}
+				
+				// 絵文字埋め込み処理
+				$destContents = $this->_convContents($destContents);
+
+				// ページ作成終了処理(HTTPヘッダ出力)
+				$gPageManager->end($request);
+				
+				// バッファを破棄
+				ob_end_flush();
+				
+				// クライアントにデータを送信
+				echo $destContents;
+			} else {
+				echo $destContents;
+			
+				// ページ作成終了処理(HTTPヘッダ出力)
+				$gPageManager->end($request);
 		
-			// バッファ内容を送信(クライアントへの送信完了)
-			ob_end_flush();
+				// mb_http_outputで設定したエンコーディングに変換して、バッファ内容を送信(クライアントへの送信完了)
+				ob_end_flush();
+			}
 		} else {		// ウィジェット単体実行モードのとき
 			// ###################ウィジェット指定で出力の場合####################
 			// ウィジェット単体を直接実行するインターフェイスで、HTTPヘッダは送信しない。
