@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 514 2008-04-19 07:03:02Z fishbone $
+ * @version    SVN: $Id: envManager.php 786 2008-06-24 03:06:55Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/core/version.php');	// システムバージョンクラス
@@ -207,6 +207,13 @@ class EnvManager
 	{
 		return M3_SYSTEM_INCLUDE_PATH . DIRECTORY_SEPARATOR . 'common';
 	}
+	/**
+	 * dataディレクトリへのパスを取得
+	 */
+	public function getDataPath()
+	{
+		return M3_SYSTEM_INCLUDE_PATH . DIRECTORY_SEPARATOR . 'data';
+	}
 	/**
 	 * Joomla用ルートディレクトリへのパスを取得
 	 */
@@ -267,6 +274,13 @@ class EnvManager
 	{
 		return M3_SYSTEM_ROOT_URL . '/resource';
 	}
+	/**
+	 * 絵文字画像用ディレクトリへのパスを取得
+	 */
+	public function getEmojiImagesUrl()
+	{
+		return M3_SYSTEM_ROOT_URL . '/images/system/emoji';
+	}
 	/**
 	 * scriptsディレクトリ(共通スクリプトディレクトリ)へのURLを取得
 	 *
@@ -931,6 +945,15 @@ class EnvManager
 	{
 		return $this->multiLanguage;
 	}
+	/**
+	 * 携帯用の入出力エンコーディングを設定
+	 *
+	 * @param string		エンコーディング
+	 */
+	public function setMobileEncoding($value)
+	{
+		$this->mobileEncoding = $value;
+	}
 	/**
 	 * 携帯用の入出力エンコーディングを取得
 	 *
