@@ -218,6 +218,7 @@ CREATE TABLE blog_comment (
     bo_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     bo_entry_id          INT            DEFAULT 0                     NOT NULL,      -- エントリーID
     bo_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    bo_parent_serial     INT            DEFAULT 0                     NOT NULL,      -- 親コメントのシリアル番号
     bo_user_id           INT            DEFAULT 0                     NOT NULL,      -- ユーザID
     bo_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
     
@@ -743,11 +744,19 @@ INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author,
 DELETE FROM _widgets WHERE wd_id = 'reserve_main';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('reserve_main',            '予約 - メイン',         'RESM', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, '予約管理のメインプログラム。',          false,           false,       true,         true,        true,         true,               false,true,           0, now(), now());
-
 DELETE FROM _widgets WHERE wd_id = 'ec_product_random_box';
 INSERT INTO _widgets
 (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('ec_product_random_box',               'Eコマース - 商品ランダム表示',                   'ECPR', '1.0.0',  '',  'Naoki Hirata', 'Magic3.org', 'GPL', 10, '商品をランダムに表示する。', 'jquery.easing,jquery.jcarousel',    false,           true,       true,         true,        true,        false,               false,true,           0, now(), now());
+DELETE FROM _widgets WHERE wd_id = 'blog_category_menu';
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('blog_category_menu',   'ブログ - カテゴリーメニュー', 'BGCM', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'ブログカテゴリメニュー',          false,           false,       true,         true,        false,         false,               false,true,           0, now(), now());
+DELETE FROM _widgets WHERE wd_id = 'blog_archive_menu';
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('blog_archive_menu',   'ブログ - アーカイブメニュー', 'BGAM', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'ブログアーカイブメニュー',          false,           false,       true,         true,        false,         false,               false,true,           0, now(), now());
+DELETE FROM _widgets WHERE wd_id = 'test_fckeditor';
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('test_fckeditor',     'FCKEditorテスト用',           'TSFC', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'FCKEditorテスト用のプログラム',          false,           false,       true,         true,        true,        false,               false,true,           0, now(), now());
 
 -- ウィジェット情報(携帯用)
 DELETE FROM _widgets WHERE wd_id = 'm/sample';
