@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_m_contentWidgetContainer.php 736 2008-06-12 01:26:38Z fishbone $
+ * @version    SVN: $Id: admin_m_contentWidgetContainer.php 782 2008-06-23 10:13:53Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -153,6 +153,7 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 	{
 		global $gEnvManager;
 		global $gPageManager;
+		global $gTextConvManager;
 		
 		// ユーザ情報、表示言語
 		$userId = $gEnvManager->getCurrentUserId();
@@ -179,7 +180,10 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 				$contentId = 0;// コンテンツID初期化
 				$default = 0;
 				$key = '';
-				//$ret = $this->db->addContentItem(0, $langId, $name, ''/*説明*/, $html, $visible, $default, $key, $userId, $newSerial);
+				
+				// 絵文字画像タグをMagic3内部タグに変換
+				$gTextConvManager->convToEmojiTag($html, $html);
+				
 				$ret = $this->db->updateContentItem(self::CONTENT_TYPE, $contentId, $langId, $name, $html, 1/*コンテンツ表示*/, $default, $key, $userId, $newContentId, $newSerial);
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
@@ -196,6 +200,9 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 			
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
+				// 絵文字画像タグをMagic3内部タグに変換
+				$gTextConvManager->convToEmojiTag($html, $html);
+				
 				$contentId = $request->trimValueOf('contentid');		// コンテンツID
 				$ret = $this->db->updateContentItem(self::CONTENT_TYPE, $contentId, $langId, $name, $html, 1/*コンテンツ表示*/, $default, $key, $userId, $newContentId, $newSerial);
 				if ($ret){
@@ -246,7 +253,6 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 			if ($ret){
 				$contentId = $row['cn_id'];		// コンテンツID
 				$name = $row['cn_name'];		// コンテンツ名前
-				$html = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $row['cn_html']);				// HTML
 				$key = $row['cn_key'];					// 外部参照用キー
 				$update_user = $this->convertToDispString($row['lu_name']);// 更新者
 				$update_dt = $this->convertToDispDateTime($row['cn_create_dt']);
@@ -254,6 +260,10 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 				// 項目表示、デフォルト値チェックボックス
 				$visible = $row['cn_visible'];
 				$default = $row['cn_default'];
+				
+				// コンテンツの変換
+				$html = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $row['cn_html']);	// Magic3ルートURLの変換
+				$gTextConvManager->convFromEmojiTag($html, $html);// Magic3内部タグから絵文字画像タグに変換
 			} else {
 				$this->serialNo = 0;
 			}
